@@ -4,17 +4,16 @@ Discord API Wrapper
 
 A basic wrapper for the Discord API.
 
-:copyright: (c) 2015-present Rapptz
-:copyright: (c) 2021-present tag-epic
+:copyright: (c) 2015-2021 Rapptz
+:copyright: (c) 2021-present Nextcord Developers
 :license: MIT, see LICENSE for more details.
-
 """
 
 __title__ = "nextcord"
-__author__ = "tag-epic & Rapptz"
+__author__ = "Nextcord Developers & Rapptz"
 __license__ = "MIT"
-__copyright__ = "Copyright 2015-present Rapptz & tag-epic"
-__version__ = "2.3.2"
+__copyright__ = "Copyright 2015-2021 Rapptz & 2021-present Nextcord Developers"
+__version__ = "2.4.2"
 
 __path__ = __import__("pkgutil").extend_path(__path__, __name__)
 
@@ -54,6 +53,7 @@ from .player import *
 from .raw_models import *
 from .reaction import *
 from .role import *
+from .role_connections import *
 from .scheduled_events import *
 from .shard import *
 from .stage_instance import *
@@ -75,6 +75,6 @@ class VersionInfo(NamedTuple):
     serial: int
 
 
-version_info: VersionInfo = VersionInfo(major=2, minor=3, micro=2, releaselevel="final", serial=0)
+version_info: VersionInfo = VersionInfo(major=2, minor=4, micro=0, releaselevel="final", serial=0)
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
