@@ -1,26 +1,4 @@
-"""
-The MIT License (MIT)
-
-Copyright (c) 2022-present tag-epic
-
-Permission is hereby granted, free of charge, to any person obtaining a
-copy of this software and associated documentation files (the "Software"),
-to deal in the Software without restriction, including without limitation
-the rights to use, copy, modify, merge, publish, distribute, sublicense,
-and/or sell copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
-OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-DEALINGS IN THE SOFTWARE.
-"""
+# SPDX-License-Identifier: MIT
 
 from __future__ import annotations
 
@@ -77,6 +55,22 @@ class AutoModerationTriggerMetadata:
 
             This is ``None`` and cannot be provided if the trigger type of the rule is not
             :attr:`AutoModerationTriggerType.keyword`.
+    regex_patterns: Optional[List[:class:`str`]]
+        A list of regex patterns which will be matched with content. Can only be up to 10 patterns.
+
+        .. versionadded:: 2.4
+
+        .. note::
+
+            This is ``None`` and cannot be provided if the trigger type of the rule is not
+            :attr:`AutoModerationTriggerType.keyword`.
+
+        .. warning::
+
+            The flavor of regex used is Rust flavor and has no guarantees of working with
+            the :mod:`re` module.
+            Each regex pattern must be 75 characters or less.
+
     presets: List[:class:`KeywordPresetType`]
         A list of Discord pre-defined wordsets which will be searched for in content.
 
@@ -105,17 +99,19 @@ class AutoModerationTriggerMetadata:
             This is ``None`` and cannot be provided if the trigger type of this rule is not :attr:`AutoModerationTriggerType.mention_spam`.
     """
 
-    __slots__ = ("keyword_filter", "presets", "allow_list", "mention_total_limit")
+    __slots__ = ("keyword_filter", "regex_patterns", "presets", "allow_list", "mention_total_limit")
 
     def __init__(
         self,
         *,
         keyword_filter: Optional[List[str]] = None,
+        regex_patterns: Optional[List[str]] = None,
         presets: Optional[List[KeywordPresetType]] = None,
         allow_list: Optional[List[str]] = None,
         mention_total_limit: Optional[int] = None,
     ) -> None:
         self.keyword_filter: Optional[List[str]] = keyword_filter
+        self.regex_patterns: Optional[List[str]] = regex_patterns
         self.presets: Optional[List[KeywordPresetType]] = presets
         self.allow_list: Optional[List[str]] = allow_list
         self.mention_total_limit: Optional[int] = mention_total_limit
@@ -123,6 +119,7 @@ class AutoModerationTriggerMetadata:
     @classmethod
     def from_data(cls, data: TriggerMetadataPayload):
         keyword_filter = data.get("keyword_filter")
+        regex_patterns = data.get("regex_patterns")
         presets = (
             [try_enum(KeywordPresetType, preset) for preset in data["presets"]]
             if "presets" in data
@@ -133,6 +130,7 @@ class AutoModerationTriggerMetadata:
 
         return cls(
             keyword_filter=keyword_filter,
+            regex_patterns=regex_patterns,
             presets=presets,
             allow_list=allow_list,
             mention_total_limit=mention_total_limit,
@@ -145,6 +143,9 @@ class AutoModerationTriggerMetadata:
         if self.keyword_filter is not None:
             payload["keyword_filter"] = self.keyword_filter
 
+        if self.regex_patterns is not None:
+            payload["regex_patterns"] = self.regex_patterns
+
         if self.presets is not None:
             payload["presets"] = [enum.value for enum in self.presets]
 
@@ -188,7 +189,7 @@ class AutoModerationActionMetadata:
 
     def __init__(
         self, *, channel: Optional[Snowflake] = None, duration_seconds: Optional[int] = None
-    ):
+    ) -> None:
         self.channel_id: Optional[int] = channel.id if channel is not None else None
         self.duration_seconds: Optional[int] = duration_seconds
 
@@ -338,7 +339,7 @@ class AutoModerationRule(Hashable):
         "exempt_channels",
     )
 
-    def __init__(self, *, data: AutoModerationRulePayload, state: ConnectionState):
+    def __init__(self, *, data: AutoModerationRulePayload, state: ConnectionState) -> None:
         self._state = state
         self.id: int = int(data["id"])
         self.guild_id: int = int(data["guild_id"])
