@@ -1,36 +1,16 @@
-"""
-The MIT License (MIT)
-
-Copyright (c) 2015-present Rapptz
-
-Permission is hereby granted, free of charge, to any person obtaining a
-copy of this software and associated documentation files (the "Software"),
-to deal in the Software without restriction, including without limitation
-the rights to use, copy, modify, merge, publish, distribute, sublicense,
-and/or sell copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
-OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-DEALINGS IN THE SOFTWARE.
-"""
+# SPDX-License-Identifier: MIT
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, ClassVar, Dict, List, Optional, Tuple, Type, TypeVar, Union
+from typing import TYPE_CHECKING, ClassVar, List, Literal, Optional, Tuple, TypeVar, Union, cast
 
 from .enums import ButtonStyle, ComponentType, TextInputStyle, try_enum
 from .partial_emoji import PartialEmoji, _EmojiTag
 from .utils import MISSING, get_slots
 
 if TYPE_CHECKING:
+    from typing_extensions import Self
+
     from .channel import ChannelType
     from .emoji import Emoji
     from .types.components import (
@@ -94,8 +74,8 @@ class Component:
         return f"<{self.__class__.__name__} {attrs}>"
 
     @classmethod
-    def _raw_construct(cls: Type[C], **kwargs) -> C:
-        self: C = cls.__new__(cls)
+    def _raw_construct(cls, **kwargs) -> Self:
+        self = cls.__new__(cls)
         for slot in get_slots(cls):
             try:
                 value = kwargs[slot]
@@ -105,7 +85,7 @@ class Component:
                 setattr(self, slot, value)
         return self
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> ComponentPayload:
         raise NotImplementedError
 
 
@@ -130,15 +110,15 @@ class ActionRow(Component):
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
-    def __init__(self, data: ComponentPayload):
+    def __init__(self, data: ComponentPayload) -> None:
         self.type: ComponentType = try_enum(ComponentType, data["type"])
         self.children: List[Component] = [_component_factory(d) for d in data.get("components", [])]
 
     def to_dict(self) -> ActionRowPayload:
         return {
-            "type": int(self.type),
+            "type": cast(Literal[1], int(self.type)),
             "components": [child.to_dict() for child in self.children],
-        }  # type: ignore
+        }
 
 
 class Button(Component):
@@ -181,7 +161,7 @@ class Button(Component):
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
-    def __init__(self, data: ButtonComponentPayload):
+    def __init__(self, data: ButtonComponentPayload) -> None:
         self.type: ComponentType = try_enum(ComponentType, data["type"])
         self.style: ButtonStyle = try_enum(ButtonStyle, data["style"])
         self.custom_id: Optional[str] = data.get("custom_id")
@@ -244,7 +224,7 @@ class SelectMenuBase(Component):
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
-    def __init__(self, data: SelectMenuBasePayload):
+    def __init__(self, data: SelectMenuBasePayload) -> None:
         self.custom_id: str = data["custom_id"]
         self.disabled: bool = data.get("disabled", False)
         self.placeholder: Optional[str] = data.get("placeholder")
@@ -302,7 +282,7 @@ class StringSelectMenu(SelectMenuBase):
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
-    def __init__(self, data: SelectMenuPayload):
+    def __init__(self, data: SelectMenuPayload) -> None:
         super().__init__(data)
         self.type = ComponentType.select
         self.options: List[SelectOption] = [
@@ -314,7 +294,7 @@ class StringSelectMenu(SelectMenuBase):
             "type": self.type.value,
             "options": [op.to_dict() for op in self.options],
             **super().to_dict(),
-        }  # type: ignore -- fixed in pyright 1.1.278
+        }
 
         return payload
 
@@ -355,12 +335,12 @@ class UserSelectMenu(SelectMenuBase):
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
-    def __init__(self, data: UserSelectMenuPayload):
+    def __init__(self, data: UserSelectMenuPayload) -> None:
         super().__init__(data)
         self.type = ComponentType.user_select
 
     def to_dict(self) -> UserSelectMenuPayload:
-        payload: UserSelectMenuPayload = {"type": self.type.value, **super().to_dict()}  # type: ignore -- fixed in pyright 1.1.278
+        payload: UserSelectMenuPayload = {"type": self.type.value, **super().to_dict()}
 
         return payload
 
@@ -398,12 +378,12 @@ class RoleSelectMenu(SelectMenuBase):
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
-    def __init__(self, data: RoleSelectMenuPayload):
+    def __init__(self, data: RoleSelectMenuPayload) -> None:
         super().__init__(data)
         self.type = ComponentType.role_select
 
     def to_dict(self) -> RoleSelectMenuPayload:
-        payload: RoleSelectMenuPayload = {"type": self.type.value, **super().to_dict()}  # type: ignore -- fixed in pyright 1.1.278
+        payload: RoleSelectMenuPayload = {"type": self.type.value, **super().to_dict()}
 
         return payload
 
@@ -441,12 +421,12 @@ class MentionableSelectMenu(SelectMenuBase):
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
-    def __init__(self, data: MentionableSelectMenuPayload):
+    def __init__(self, data: MentionableSelectMenuPayload) -> None:
         super().__init__(data)
         self.type = ComponentType.mentionable_select
 
     def to_dict(self) -> MentionableSelectMenuPayload:
-        payload: MentionableSelectMenuPayload = {"type": self.type.value, **super().to_dict()}  # type: ignore -- fixed in pyright 1.1.278
+        payload: MentionableSelectMenuPayload = {"type": self.type.value, **super().to_dict()}
 
         return payload
 
@@ -486,7 +466,7 @@ class ChannelSelectMenu(SelectMenuBase):
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
-    def __init__(self, data: ChannelSelectMenuPayload):
+    def __init__(self, data: ChannelSelectMenuPayload) -> None:
         super().__init__(data)
         self.type = ComponentType.channel_select
         self.channel_types: List[ChannelType] = [
@@ -494,7 +474,7 @@ class ChannelSelectMenu(SelectMenuBase):
         ]
 
     def to_dict(self) -> ChannelSelectMenuPayload:
-        payload: ChannelSelectMenuPayload = {"type": self.type.value, **super().to_dict()}  # type: ignore -- fixed in pyright 1.1.278
+        payload: ChannelSelectMenuPayload = {"type": self.type.value, **super().to_dict()}
         if self.channel_types:
             payload["channel_types"] = [t.value for t in self.channel_types]
 
@@ -608,7 +588,6 @@ class SelectOption:
 
 
 class TextInput(Component):
-
     __slots__: Tuple[str, ...] = (
         "style",
         "custom_id",
@@ -622,7 +601,7 @@ class TextInput(Component):
 
     __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
 
-    def __init__(self, data: TextInputComponentPayload):
+    def __init__(self, data: TextInputComponentPayload) -> None:
         self.type: ComponentType = try_enum(ComponentType, data["type"])
         self.style: TextInputStyle = try_enum(
             TextInputStyle,
