@@ -1,27 +1,4 @@
-"""
-The MIT License (MIT)
-
-Copyright (c) 2015-present Rapptz
-Copyright (c) 2021-present tag-epic
-
-Permission is hereby granted, free of charge, to any person obtaining a
-copy of this software and associated documentation files (the "Software"),
-to deal in the Software without restriction, including without limitation
-the rights to use, copy, modify, merge, publish, distribute, sublicense,
-and/or sell copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
-OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-DEALINGS IN THE SOFTWARE.
-"""
+# SPDX-License-Identifier: MIT
 
 from __future__ import annotations
 
@@ -78,7 +55,7 @@ __all__ = (
 
 
 class CheckWrapper(CallbackWrapper):
-    def __init__(self, callback: Union[Callable, CallbackWrapper], predicate):
+    def __init__(self, callback: Union[Callable, CallbackWrapper], predicate) -> None:
         super().__init__(callback)
 
         if not asyncio.iscoroutinefunction(predicate):
@@ -94,7 +71,7 @@ class CheckWrapper(CallbackWrapper):
     def __call__(self, *args, **kwargs):
         return self.predicate(*args, **kwargs)
 
-    def modify(self, app_cmd: BaseApplicationCommand):
+    def modify(self, app_cmd: BaseApplicationCommand) -> None:
         app_cmd.checks.append(self.predicate)
 
 
@@ -755,7 +732,7 @@ def application_command_before_invoke(coro) -> AC:
     """
 
     class BeforeInvokeModifier(CallbackWrapper):
-        def modify(self, app_cmd: BaseApplicationCommand):
+        def modify(self, app_cmd: BaseApplicationCommand) -> None:
             app_cmd._callback_before_invoke = coro
 
     def decorator(
@@ -774,7 +751,7 @@ def application_command_after_invoke(coro) -> AC:
     """
 
     class AfterInvokeModifier(CallbackWrapper):
-        def modify(self, app_cmd: BaseApplicationCommand):
+        def modify(self, app_cmd: BaseApplicationCommand) -> None:
             app_cmd._callback_after_invoke = coro
 
     def decorator(
