@@ -1,25 +1,4 @@
-"""
-The MIT License (MIT)
-Copyright (c) 2021-present tag-epic
-
-Permission is hereby granted, free of charge, to any person obtaining a
-copy of this software and associated documentation files (the "Software"),
-to deal in the Software without restriction, including without limitation
-the rights to use, copy, modify, merge, publish, distribute, sublicense,
-and/or sell copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
-OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-DEALINGS IN THE SOFTWARE.
-"""
+# SPDX-License-Identifier: MIT
 
 from typing import Any, Callable, List, Optional, Union
 
@@ -28,7 +7,6 @@ from nextcord.channel import PartialMessageable
 from nextcord.errors import ApplicationCheckFailure
 from nextcord.interactions import Interaction
 from nextcord.threads import Thread
-from nextcord.types.snowflake import Snowflake, SnowflakeList
 
 __all__ = (
     "ApplicationCheckAnyFailure",
@@ -61,11 +39,11 @@ class ApplicationCheckAnyFailure(ApplicationCheckFailure):
 
     def __init__(
         self,
-        checks: List[ApplicationCheckFailure],
-        errors: List[Callable[[Interaction], bool]],
+        checks: List[Callable[[Interaction], bool]],
+        errors: List[ApplicationCheckFailure],
     ) -> None:
-        self.checks: List[ApplicationCheckFailure] = checks
-        self.errors: List[Callable[[Interaction], bool]] = errors
+        self.checks: List[Callable[[Interaction], bool]] = checks
+        self.errors: List[ApplicationCheckFailure] = errors
         super().__init__("You do not have permission to run this command.")
 
 
@@ -94,8 +72,8 @@ class ApplicationMissingRole(ApplicationCheckFailure):
         This is the parameter passed to :func:`~.application_checks.has_role`.
     """
 
-    def __init__(self, missing_role: Snowflake) -> None:
-        self.missing_role: Snowflake = missing_role
+    def __init__(self, missing_role: Union[str, int]) -> None:
+        self.missing_role: Union[str, int] = missing_role
         message = f"Role {missing_role!r} is required to run this command."
         super().__init__(message)
 
@@ -113,8 +91,8 @@ class ApplicationMissingAnyRole(ApplicationCheckFailure):
         These are the parameters passed to :func:`has_any_role`.
     """
 
-    def __init__(self, missing_roles: SnowflakeList) -> None:
-        self.missing_roles: SnowflakeList = missing_roles
+    def __init__(self, missing_roles: List[Union[str, int]]) -> None:
+        self.missing_roles: List[Union[str, int]] = missing_roles
 
         missing = [f"'{role}'" for role in missing_roles]
 
@@ -141,8 +119,8 @@ class ApplicationBotMissingRole(ApplicationCheckFailure):
         This is the parameter passed to :func:`has_role`.
     """
 
-    def __init__(self, missing_role: Snowflake) -> None:
-        self.missing_role: Snowflake = missing_role
+    def __init__(self, missing_role: Union[str, int]) -> None:
+        self.missing_role: Union[str, int] = missing_role
         message = f"Bot requires the role {missing_role!r} to run this command"
         super().__init__(message)
 
@@ -163,8 +141,8 @@ class ApplicationBotMissingAnyRole(ApplicationCheckFailure):
 
     """
 
-    def __init__(self, missing_roles: SnowflakeList) -> None:
-        self.missing_roles: SnowflakeList = missing_roles
+    def __init__(self, missing_roles: List[Union[str, int]]) -> None:
+        self.missing_roles: List[Union[str, int]] = missing_roles
 
         missing = [f"'{role}'" for role in missing_roles]
 
@@ -265,7 +243,7 @@ class ApplicationNSFWChannelRequired(ApplicationCheckFailure):
     """
 
     def __init__(self, channel: Optional[Union[GuildChannel, Thread, PartialMessageable]]) -> None:
-        self.channel = channel
+        self.channel: Optional[Union[GuildChannel, Thread, PartialMessageable]] = channel
         super().__init__(f"Channel '{channel}' needs to be NSFW for this command to work.")
 
 
