@@ -1,28 +1,6 @@
 # -*- coding: utf-8 -*-
 
-"""
-The MIT License (MIT)
-
-Copyright (c) 2015-present Rapptz
-
-Permission is hereby granted, free of charge, to any person obtaining a
-copy of this software and associated documentation files (the "Software"),
-to deal in the Software without restriction, including without limitation
-the rights to use, copy, modify, merge, publish, distribute, sublicense,
-and/or sell copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
-OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-DEALINGS IN THE SOFTWARE.
-"""
+# SPDX-License-Identifier: MIT
 
 from __future__ import annotations
 
@@ -36,6 +14,7 @@ from .embeds import Embed
 from .enums import InteractionResponseType, InteractionType, try_enum
 from .errors import ClientException, HTTPException, InteractionResponded, InvalidArgument
 from .file import File
+from .flags import MessageFlags
 from .member import Member
 from .message import Attachment, Message
 from .mixins import Hashable
@@ -105,11 +84,11 @@ class InteractionAttached(dict):
             await interaction.response.send_message(data)
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.__dict__ = self
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"<InteractionAttached {super().__repr__()}>"
 
 
@@ -194,7 +173,7 @@ class Interaction(Hashable, Generic[ClientT]):
         "_cs_channel",
     )
 
-    def __init__(self, *, data: InteractionPayload, state: ConnectionState):
+    def __init__(self, *, data: InteractionPayload, state: ConnectionState) -> None:
         self._state: ConnectionState = state
         self._session: ClientSession = state.http._HTTPClient__session  # type: ignore
         # TODO: this is so janky, accessing a hidden double attribute
@@ -205,7 +184,7 @@ class Interaction(Hashable, Generic[ClientT]):
         ] = None
         self._from_data(data)
 
-    def _from_data(self, data: InteractionPayload):
+    def _from_data(self, data: InteractionPayload) -> None:
         self.id: int = int(data["id"])
         self.type: InteractionType = try_enum(InteractionType, data["type"])
         self.data: Optional[InteractionData] = data.get("data")
@@ -279,7 +258,7 @@ class Interaction(Hashable, Generic[ClientT]):
 
     def _set_application_command(
         self, app_cmd: Union[SlashApplicationSubcommand, BaseApplicationCommand]
-    ):
+    ) -> None:
         self.application_command = app_cmd
 
     @utils.cached_slot_property("_cs_channel")
@@ -498,7 +477,7 @@ class Interaction(Hashable, Generic[ClientT]):
 
         if delay is not None:
 
-            async def inner_call(delay: float = delay):
+            async def inner_call(delay: float = delay) -> None:
                 await asyncio.sleep(delay)
                 try:
                     await delete_func
@@ -519,9 +498,11 @@ class Interaction(Hashable, Generic[ClientT]):
         files: List[File] = MISSING,
         view: View = MISSING,
         tts: bool = False,
-        ephemeral: bool = False,
         delete_after: Optional[float] = None,
         allowed_mentions: AllowedMentions = MISSING,
+        flags: Optional[MessageFlags] = None,
+        ephemeral: Optional[bool] = None,
+        suppress_embeds: Optional[bool] = None,
     ) -> Union[PartialInteractionMessage, WebhookMessage]:
         """|coro|
 
@@ -567,6 +548,8 @@ class Interaction(Hashable, Generic[ClientT]):
                 ephemeral=ephemeral,
                 delete_after=delete_after,
                 allowed_mentions=allowed_mentions,
+                flags=flags,
+                suppress_embeds=suppress_embeds,
             )
         return await self.followup.send(
             content=content,  # type: ignore
@@ -579,6 +562,8 @@ class Interaction(Hashable, Generic[ClientT]):
             ephemeral=ephemeral,
             delete_after=delete_after,
             allowed_mentions=allowed_mentions,
+            flags=flags,
+            suppress_embeds=suppress_embeds,
         )
 
     async def edit(self, *args, **kwargs) -> Optional[Message]:
@@ -636,7 +621,7 @@ class InteractionResponse:
         "_parent",
     )
 
-    def __init__(self, parent: Interaction):
+    def __init__(self, parent: Interaction) -> None:
         self._parent: Interaction = parent
         self._responded: bool = False
 
@@ -774,14 +759,21 @@ class InteractionResponse:
         files: List[File] = MISSING,
         view: View = MISSING,
         tts: bool = False,
-        ephemeral: bool = False,
         delete_after: Optional[float] = None,
         allowed_mentions: Optional[AllowedMentions] = MISSING,
+        flags: Optional[MessageFlags] = None,
+        ephemeral: Optional[bool] = None,
+        suppress_embeds: Optional[bool] = None,
     ) -> PartialInteractionMessage:
         """|coro|
 
         Responds to this interaction by sending a message.
 
+        .. versionchanged:: 2.4
+
+            ``ephemeral`` can now accept ``None`` to indicate that
+            ``flags`` should be used.
+
         Parameters
         ----------
         content: Optional[:class:`str`]
@@ -812,6 +804,15 @@ class InteractionResponse:
         allowed_mentions: :class:`AllowedMentions`
             Controls the mentions being processed in this message.
             See :meth:`.abc.Messageable.send` for more information.
+        flags: Optional[:class:`~nextcord.MessageFlags`]
+            The message flags being set for this message.
+            Currently only :class:`~nextcord.MessageFlags.suppress_embeds` is able to be set.
+
+            .. versionadded:: 2.4
+        suppress_embeds: Optional[:class:`bool`]
+            Whether to suppress embeds on this message.
+
+            .. versionadded:: 2.4
 
         Raises
         ------
@@ -865,8 +866,15 @@ class InteractionResponse:
         if content is not None:
             payload["content"] = str(content)
 
-        if ephemeral:
-            payload["flags"] = 64
+        if flags is None:
+            flags = MessageFlags()
+        if suppress_embeds is not None:
+            flags.suppress_embeds = suppress_embeds
+        if ephemeral is not None:
+            flags.ephemeral = ephemeral
+
+        if flags.value != 0:
+            payload["flags"] = flags.value
 
         if view is not MISSING:
             payload["components"] = view.to_components()
@@ -1083,7 +1091,7 @@ class InteractionResponse:
 class _InteractionMessageState:
     __slots__ = ("_parent", "_interaction")
 
-    def __init__(self, interaction: Interaction, parent: ConnectionState):
+    def __init__(self, interaction: Interaction, parent: ConnectionState) -> None:
         self._interaction: Interaction = interaction
         self._parent: ConnectionState = parent
 
@@ -1245,7 +1253,7 @@ class PartialInteractionMessage(_InteractionMessageMixin):
         :class:`Interaction` that it is associated with but not that of the full :class:`InteractionMessage`.
     """
 
-    def __init__(self, state: _InteractionMessageState):
+    def __init__(self, state: _InteractionMessageState) -> None:
         self._state = state
 
     async def fetch(self) -> InteractionMessage:
@@ -1292,7 +1300,7 @@ class PartialInteractionMessage(_InteractionMessageMixin):
         """Optional[:class:`Guild`]: The guild the interaction was sent from."""
         return self._state._interaction.guild
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"<{self.__class__.__name__} author={self.author!r} channel={self.channel!r} guild={self.guild!r}>"
 
     def __eq__(self, other: object) -> bool:
