@@ -1,27 +1,5 @@
-"""
-The MIT License (MIT)
-
-Copyright (c) 2015-2021 Rapptz
-Copyright (c) 2021-present tag-epic
-
-Permission is hereby granted, free of charge, to any person obtaining a
-copy of this software and associated documentation files (the "Software"),
-to deal in the Software without restriction, including without limitation
-the rights to use, copy, modify, merge, publish, distribute, sublicense,
-and/or sell copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
-OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-DEALINGS IN THE SOFTWARE.
-"""
+# SPDX-License-Identifier: MIT
+# pyright: strict, reportPrivateUsage = false
 
 from __future__ import annotations
 
@@ -33,10 +11,12 @@ from typing import (
     AsyncIterator,
     Awaitable,
     Callable,
+    Generic,
     List,
     Optional,
     TypeVar,
     Union,
+    cast,
 )
 
 from .audit_logs import AuditLogEntry
@@ -44,6 +24,7 @@ from .auto_moderation import AutoModerationRule
 from .bans import BanEntry
 from .errors import NoMoreItems
 from .object import Object
+from .types.user import PartialUser as PartialUserPayload
 from .utils import maybe_coroutine, snowflake_time, time_snowflake
 
 __all__ = (
@@ -58,18 +39,26 @@ __all__ = (
 )
 
 if TYPE_CHECKING:
-    from .abc import Snowflake
+    from .abc import Messageable, Snowflake, SnowflakeTime
+    from .audit_logs import AuditLogEntry
+    from .client import Client
+    from .enums import AuditLogAction
     from .guild import Guild
+    from .http import HTTPClient
     from .member import Member
     from .message import Message
     from .scheduled_events import ScheduledEvent, ScheduledEventUser  # noqa: F401
+    from .state import ConnectionState
     from .threads import Thread
-    from .types.audit_log import AuditLog as AuditLogPayload, AuditLogEntry as AuditLogEntryPayload
+    from .types.audit_log import AuditLog as AuditLogPayload
     from .types.guild import Ban as BanPayload, Guild as GuildPayload
+    from .types.member import MemberWithUser
     from .types.message import Message as MessagePayload
-    from .types.scheduled_events import ScheduledEventUser as ScheduledEventUserPayload
-    from .types.threads import Thread as ThreadPayload
-    from .types.user import PartialUser as PartialUserPayload
+    from .types.scheduled_events import (
+        ScheduledEvent as ScheduledEventPayload,
+        ScheduledEventUser as ScheduledEventUserPayload,
+    )
+    from .types.threads import Thread as ThreadPayload, ThreadPaginationPayload
     from .user import User
 
 T = TypeVar("T")
@@ -85,8 +74,8 @@ class _AsyncIterator(AsyncIterator[T]):
     async def next(self) -> T:
         raise NotImplementedError
 
-    def get(self, **attrs: Any) -> Awaitable[Optional[T]]:
-        def predicate(elem: T):
+    def get(self, **attrs: T) -> Awaitable[Optional[T]]:
+        def predicate(elem: T) -> bool:
             for attr, val in attrs.items():
                 nested = attr.split("__")
                 obj = elem
@@ -115,7 +104,7 @@ class _AsyncIterator(AsyncIterator[T]):
             raise ValueError("Async iterator chunk sizes must be greater than 0")
         return _ChunkedAsyncIterator(self, max_size)
 
-    def map(self, func: _Func[T, OT]) -> _MappedAsyncIterator[OT]:
+    def map(self, func: _Func[T, OT]) -> _MappedAsyncIterator[T, OT]:
         return _MappedAsyncIterator(self, func)
 
     def filter(self, predicate: _Func[T, bool]) -> _FilteredAsyncIterator[T]:
@@ -131,14 +120,14 @@ class _AsyncIterator(AsyncIterator[T]):
             raise StopAsyncIteration()
 
 
-def _identity(x):
+def _identity(x: T) -> T:
     return x
 
 
 class _ChunkedAsyncIterator(_AsyncIterator[List[T]]):
-    def __init__(self, iterator, max_size):
-        self.iterator = iterator
-        self.max_size = max_size
+    def __init__(self, iterator: _AsyncIterator[T], max_size: int) -> None:
+        self.iterator: _AsyncIterator[T] = iterator
+        self.max_size: int = max_size
 
     async def next(self) -> List[T]:
         ret: List[T] = []
@@ -156,25 +145,25 @@ class _ChunkedAsyncIterator(_AsyncIterator[List[T]]):
         return ret
 
 
-class _MappedAsyncIterator(_AsyncIterator[T]):
-    def __init__(self, iterator, func):
-        self.iterator = iterator
-        self.func = func
+class _MappedAsyncIterator(_AsyncIterator[OT], Generic[T, OT]):
+    def __init__(self, iterator: _AsyncIterator[T], func: _Func[T, OT]) -> None:
+        self.iterator: _AsyncIterator[T] = iterator
+        self.func: _Func[T, Any] = func
 
-    async def next(self) -> T:
+    async def next(self) -> OT:
         # this raises NoMoreItems and will propagate appropriately
         item = await self.iterator.next()
         return await maybe_coroutine(self.func, item)
 
 
 class _FilteredAsyncIterator(_AsyncIterator[T]):
-    def __init__(self, iterator, predicate):
-        self.iterator = iterator
+    def __init__(self, iterator: _AsyncIterator[T], predicate: _Func[T, Any]) -> None:
+        self.iterator: _AsyncIterator[T] = iterator
 
         if predicate is None:
             predicate = _identity
 
-        self.predicate = predicate
+        self.predicate: _Func[T, Any] = predicate
 
     async def next(self) -> T:
         getter = self.iterator.next
@@ -188,17 +177,17 @@ class _FilteredAsyncIterator(_AsyncIterator[T]):
 
 
 class ReactionIterator(_AsyncIterator[Union["User", "Member"]]):
-    def __init__(self, message, emoji, limit=100, after=None):
-        self.message = message
-        self.limit = limit
-        self.after = after
-        state = message._state
-        self.getter = state.http.get_reaction_users
-        self.state = state
-        self.emoji = emoji
-        self.guild = message.guild
-        self.channel_id = message.channel.id
-        self.users = asyncio.Queue()
+    def __init__(
+        self, message: Message, emoji: str, limit: int = 100, after: Optional[Snowflake] = None
+    ) -> None:
+        self.message: Message = message
+        self.limit: int = limit
+        self.after: Optional[Snowflake] = after
+        self.state: ConnectionState = message._state
+        self.emoji: str = emoji
+        self.guild: Optional[Guild] = message.guild
+        self.channel_id: int = message.channel.id
+        self.users: asyncio.Queue[Union[Member, User]] = asyncio.Queue()
 
     async def next(self) -> Union[User, Member]:
         if self.users.empty():
@@ -209,7 +198,7 @@ class ReactionIterator(_AsyncIterator[Union["User", "Member"]]):
         except asyncio.QueueEmpty:
             raise NoMoreItems()
 
-    async def fill_users(self):
+    async def fill_users(self) -> None:
         # this is a hack because >circular imports<
         from .user import User
 
@@ -217,9 +206,13 @@ class ReactionIterator(_AsyncIterator[Union["User", "Member"]]):
             retrieve = self.limit if self.limit <= 100 else 100
 
             after = self.after.id if self.after else None
-            data: List[PartialUserPayload] = await self.getter(
-                self.channel_id, self.message.id, self.emoji, retrieve, after=after
+            data: List[PartialUserPayload] = cast(
+                List[PartialUserPayload],
+                await self.state.http.get_reaction_users(
+                    self.channel_id, self.message.id, self.emoji, retrieve, after=after
+                ),
             )
+            # cast needed here because of list's invariance
 
             if data:
                 self.limit -= retrieve
@@ -227,7 +220,7 @@ class ReactionIterator(_AsyncIterator[Union["User", "Member"]]):
 
             if self.guild is None or isinstance(self.guild, Object):
                 for element in reversed(data):
-                    await self.users.put(User(state=self.state, data=element))  # type: ignore
+                    await self.users.put(User(state=self.state, data=element))
             else:
                 for element in reversed(data):
                     member_id = int(element["id"])
@@ -235,7 +228,7 @@ class ReactionIterator(_AsyncIterator[Union["User", "Member"]]):
                     if member is not None:
                         await self.users.put(member)
                     else:
-                        await self.users.put(User(state=self.state, data=element))  # type: ignore
+                        await self.users.put(User(state=self.state, data=element))
 
 
 class HistoryIterator(_AsyncIterator["Message"]):
@@ -272,8 +265,15 @@ class HistoryIterator(_AsyncIterator["Message"]):
         ``True`` if ``after`` is specified, otherwise ``False``.
     """
 
-    def __init__(self, messageable, limit, before=None, after=None, around=None, oldest_first=None):
-
+    def __init__(
+        self,
+        messageable: Messageable,
+        limit: Optional[int],
+        before: Optional[SnowflakeTime] = None,
+        after: Optional[SnowflakeTime] = None,
+        around: Optional[SnowflakeTime] = None,
+        oldest_first: Optional[bool] = None,
+    ) -> None:
         if isinstance(before, datetime.datetime):
             before = Object(id=time_snowflake(before, high=False))
         if isinstance(after, datetime.datetime):
@@ -281,22 +281,22 @@ class HistoryIterator(_AsyncIterator["Message"]):
         if isinstance(around, datetime.datetime):
             around = Object(id=time_snowflake(around))
 
+        self.reverse: bool
         if oldest_first is None:
             self.reverse = after is not None
         else:
             self.reverse = oldest_first
 
-        self.messageable = messageable
-        self.limit = limit
+        self.messageable: Messageable = messageable
+        self.limit: Optional[int] = limit
         self.before: Optional[Snowflake] = before
         self.after: Optional[Snowflake] = after or OLDEST_OBJECT
         self.around: Optional[Snowflake] = around
 
         self._filter: Optional[Callable[[MessagePayload], bool]] = None  # message dict -> bool
 
-        self.state = self.messageable._state
-        self.logs_from = self.state.http.logs_from
-        self.messages = asyncio.Queue()
+        self.state: ConnectionState = self.messageable._state
+        self.messages: asyncio.Queue[Message] = asyncio.Queue()
 
         if self.around:
             if self.limit is None:
@@ -306,7 +306,7 @@ class HistoryIterator(_AsyncIterator["Message"]):
             elif self.limit == 101:
                 self.limit = 100  # Thanks discord
 
-            self._retrieve_messages = self._retrieve_messages_around_strategy  # type: ignore
+            self._retrieve_messages = self._retrieve_messages_around_strategy
             if self.before and self.after:
                 # lambda type ignores are as before/after/around are optional but exist here
                 self._filter = lambda m: self.after.id < int(m["id"]) < self.before.id  # type: ignore
@@ -316,11 +316,11 @@ class HistoryIterator(_AsyncIterator["Message"]):
                 self._filter = lambda m: self.after.id < int(m["id"])  # type: ignore
         else:
             if self.reverse:
-                self._retrieve_messages = self._retrieve_messages_after_strategy  # type: ignore
+                self._retrieve_messages = self._retrieve_messages_after_strategy
                 if self.before:
                     self._filter = lambda m: int(m["id"]) < self.before.id  # type: ignore
             else:
-                self._retrieve_messages = self._retrieve_messages_before_strategy  # type: ignore
+                self._retrieve_messages = self._retrieve_messages_before_strategy
                 if self.after and self.after != OLDEST_OBJECT:
                     self._filter = lambda m: int(m["id"]) > self.after.id  # type: ignore
 
@@ -342,7 +342,7 @@ class HistoryIterator(_AsyncIterator["Message"]):
         self.retrieve = r
         return r > 0
 
-    async def fill_messages(self):
+    async def fill_messages(self) -> None:
         if not hasattr(self, "channel"):
             # do the required set up
             channel = await self.messageable._get_channel()
@@ -362,35 +362,39 @@ class HistoryIterator(_AsyncIterator["Message"]):
             for element in data:
                 await self.messages.put(self.state.create_message(channel=channel, data=element))
 
-    async def _retrieve_messages(self, retrieve) -> List[MessagePayload]:
+    async def _retrieve_messages(self, retrieve: int) -> List[MessagePayload]:
         """Retrieve messages and update next parameters."""
         raise NotImplementedError
 
-    async def _retrieve_messages_before_strategy(self, retrieve):
+    async def _retrieve_messages_before_strategy(self, retrieve: int) -> List[MessagePayload]:
         """Retrieve messages using before parameter."""
         before = self.before.id if self.before else None
-        data: List[MessagePayload] = await self.logs_from(self.channel.id, retrieve, before=before)
+        data: List[MessagePayload] = await self.state.http.logs_from(
+            self.channel.id, retrieve, before=before
+        )
         if len(data):
             if self.limit is not None:
                 self.limit -= retrieve
             self.before = Object(id=int(data[-1]["id"]))
         return data
 
-    async def _retrieve_messages_after_strategy(self, retrieve):
+    async def _retrieve_messages_after_strategy(self, retrieve: int) -> List[MessagePayload]:
         """Retrieve messages using after parameter."""
         after = self.after.id if self.after else None
-        data: List[MessagePayload] = await self.logs_from(self.channel.id, retrieve, after=after)
+        data: List[MessagePayload] = await self.state.http.logs_from(
+            self.channel.id, retrieve, after=after
+        )
         if len(data):
             if self.limit is not None:
                 self.limit -= retrieve
             self.after = Object(id=int(data[0]["id"]))
         return data
 
-    async def _retrieve_messages_around_strategy(self, retrieve):
+    async def _retrieve_messages_around_strategy(self, retrieve: int) -> List[MessagePayload]:
         """Retrieve messages using around parameter."""
         if self.around:
             around = self.around.id if self.around else None
-            data: List[MessagePayload] = await self.logs_from(
+            data: List[MessagePayload] = await self.state.http.logs_from(
                 self.channel.id, retrieve, around=around
             )
             self.around = None
@@ -430,15 +434,14 @@ class BanIterator(_AsyncIterator["BanEntry"]):
         limit: Optional[int] = None,
         before: Optional[Snowflake] = None,
         after: Optional[Snowflake] = None,
-    ):
-        self.guild = guild
-        self.limit = limit
-        self.before = before
-        self.after = after or OLDEST_OBJECT
+    ) -> None:
+        self.guild: Guild = guild
+        self.limit: Optional[int] = limit
+        self.before: Optional[Snowflake] = before
+        self.after: Snowflake = after or OLDEST_OBJECT
 
-        self.state = self.guild._state
-        self.get_bans = self.state.http.get_bans
-        self.bans = asyncio.Queue()
+        self.state: ConnectionState = self.guild._state
+        self.bans: asyncio.Queue[BanEntry] = asyncio.Queue()
 
         if self.before:
             self._retrieve_bans = self._retrieve_bans_before_strategy
@@ -458,7 +461,7 @@ class BanIterator(_AsyncIterator["BanEntry"]):
         self.retrieve = min(self.limit, 1000) if self.limit is not None else 1000
         return self.retrieve > 0
 
-    async def fill_bans(self):
+    async def fill_bans(self) -> None:
         from .user import User
 
         if self._get_retrieve():
@@ -477,7 +480,9 @@ class BanIterator(_AsyncIterator["BanEntry"]):
     async def _retrieve_bans_before_strategy(self, retrieve: int) -> List[BanPayload]:
         """Retrieve bans using before parameter."""
         before = self.before.id if self.before else None
-        data: List[BanPayload] = await self.get_bans(self.guild.id, retrieve, before=before)
+        data: List[BanPayload] = await self.state.http.get_bans(
+            self.guild.id, retrieve, before=before
+        )
         if len(data):
             if self.limit is not None:
                 self.limit -= len(data)
@@ -487,7 +492,9 @@ class BanIterator(_AsyncIterator["BanEntry"]):
     async def _retrieve_bans_after_strategy(self, retrieve: int) -> List[BanPayload]:
         """Retrieve bans using after parameter."""
         after = self.after.id if self.after else None
-        data: List[BanPayload] = await self.get_bans(self.guild.id, retrieve, after=after)
+        data: List[BanPayload] = await self.state.http.get_bans(
+            self.guild.id, retrieve, after=after
+        )
         if len(data):
             if self.limit is not None:
                 self.limit -= len(data)
@@ -498,50 +505,43 @@ class BanIterator(_AsyncIterator["BanEntry"]):
 class AuditLogIterator(_AsyncIterator["AuditLogEntry"]):
     def __init__(
         self,
-        guild,
-        limit=None,
-        before=None,
-        after=None,
-        oldest_first=None,
-        user_id=None,
-        action_type=None,
-    ):
+        guild: Guild,
+        limit: Optional[int] = None,
+        before: Optional[SnowflakeTime] = None,
+        after: Optional[SnowflakeTime] = None,
+        oldest_first: Optional[bool] = None,
+        user_id: Optional[int] = None,
+        action_type: Optional[AuditLogAction] = None,
+    ) -> None:
         if isinstance(before, datetime.datetime):
             before = Object(id=time_snowflake(before, high=False))
         if isinstance(after, datetime.datetime):
             after = Object(id=time_snowflake(after, high=True))
 
-        if oldest_first is None:
-            self.reverse = after is not None
-        else:
-            self.reverse = oldest_first
+        # Maintain compatibility with `None` being passed in for `oldest_first`
+        self.reverse: bool = bool(oldest_first)
 
-        self.guild = guild
-        self.loop = guild._state.loop
-        self.request = guild._state.http.get_audit_logs
-        self.limit = limit
+        self.guild: Guild = guild
+        self.loop: asyncio.AbstractEventLoop = guild._state.loop
+        self.limit: Optional[int] = limit
         self.before: Optional[Snowflake] = before
-        self.user_id = user_id
-        self.action_type = action_type
-        self.after: Optional[Snowflake] = after or OLDEST_OBJECT
-        self._state = guild._state
+        self.user_id: Optional[int] = user_id
+        self.action_type: Optional[AuditLogAction] = action_type
+        self.after: Optional[Snowflake] = after
+        self._state: ConnectionState = guild._state
 
-        self._filter: Optional[Callable[[AuditLogEntryPayload], bool]] = None  # entry dict -> bool
+        self.entries: asyncio.Queue[AuditLogEntry] = asyncio.Queue()
 
-        self.entries = asyncio.Queue()
-
-        self._strategy = self._before_strategy
-        if self.after and self.after != OLDEST_OBJECT:
-            self._filter = lambda m: int(m["id"]) > self.after.id  # type: ignore
-
-    async def _before_strategy(self, retrieve):
+    async def _get_logs(self, retrieve: int):
         before = self.before.id if self.before else None
-        data: AuditLogPayload = await self.request(
+        after = self.after.id if self.after else None
+        data: AuditLogPayload = await self._state.http.get_audit_logs(
             self.guild.id,
             limit=retrieve,
             user_id=self.user_id,
             action_type=self.action_type,
             before=before,
+            after=after,
         )
 
         entries = data.get("audit_log_entries", [])
@@ -569,17 +569,15 @@ class AuditLogIterator(_AsyncIterator["AuditLogEntry"]):
         self.retrieve = r
         return r > 0
 
-    async def _fill(self):
+    async def _fill(self) -> None:
         if self._get_retrieve():
-            data = await self._strategy(self.retrieve)
+            data = await self._get_logs(self.retrieve)
             if len(data) < 100:
                 self.limit = 0  # terminate the infinite loop
 
             entries = data.get("audit_log_entries")
             if self.reverse:
                 entries = reversed(entries)
-            if self._filter:
-                entries = filter(self._filter, entries)
 
             state = self._state
 
@@ -633,32 +631,39 @@ class GuildIterator(_AsyncIterator["Guild"]):
         Object after which all guilds must be.
     """
 
-    def __init__(self, bot, limit, before=None, after=None):
+    def __init__(
+        self,
+        bot: Client,
+        limit: Optional[int],
+        before: Optional[SnowflakeTime] = None,
+        after: Optional[SnowflakeTime] = None,
+    ) -> None:
+        self.retrieve: int
 
         if isinstance(before, datetime.datetime):
             before = Object(id=time_snowflake(before, high=False))
         if isinstance(after, datetime.datetime):
             after = Object(id=time_snowflake(after, high=True))
 
-        self.bot = bot
-        self.limit = limit
+        self.bot: Client = bot
+        self.limit: Optional[int] = limit
         self.before: Optional[Snowflake] = before
         self.after: Optional[Snowflake] = after
 
         self._filter: Optional[Callable[[GuildPayload], bool]] = None
 
-        self.state = self.bot._connection
-        self.get_guilds = self.bot.http.get_guilds
-        self.guilds = asyncio.Queue()
+        self.state: ConnectionState = self.bot._connection
+        self.guilds: asyncio.Queue[Guild] = asyncio.Queue()
 
+        self.reverse: bool
         if self.before:
             self.reverse = True
-            self._retrieve_guilds = self._retrieve_guilds_before_strategy  # type: ignore
+            self._retrieve_guilds = self._retrieve_guilds_before_strategy
             if self.after:
                 self._filter = lambda m: int(m["id"]) > self.after.id  # type: ignore
         else:
             self.reverse = False
-            self._retrieve_guilds = self._retrieve_guilds_after_strategy  # type: ignore
+            self._retrieve_guilds = self._retrieve_guilds_after_strategy
 
     async def next(self) -> Guild:
         if self.guilds.empty():
@@ -678,12 +683,12 @@ class GuildIterator(_AsyncIterator["Guild"]):
         self.retrieve = r
         return r > 0
 
-    def create_guild(self, data):
+    def create_guild(self, data: GuildPayload) -> Guild:
         from .guild import Guild
 
         return Guild(state=self.state, data=data)
 
-    async def fill_guilds(self):
+    async def fill_guilds(self) -> None:
         if self._get_retrieve():
             data = await self._retrieve_guilds(self.retrieve)
             if len(data) < 200:
@@ -697,24 +702,24 @@ class GuildIterator(_AsyncIterator["Guild"]):
             for element in data:
                 await self.guilds.put(self.create_guild(element))
 
-    async def _retrieve_guilds(self, retrieve) -> List[GuildPayload]:
+    async def _retrieve_guilds(self, retrieve: int) -> List[GuildPayload]:
         """Retrieve guilds and update next parameters."""
         raise NotImplementedError
 
-    async def _retrieve_guilds_before_strategy(self, retrieve):
+    async def _retrieve_guilds_before_strategy(self, retrieve: int) -> List[GuildPayload]:
         """Retrieve guilds using before parameter."""
         before = self.before.id if self.before else None
-        data: List[GuildPayload] = await self.get_guilds(retrieve, before=before)
+        data: List[GuildPayload] = await self.bot.http.get_guilds(retrieve, before=before)
         if len(data):
             if self.limit is not None:
                 self.limit -= retrieve
             self.before = Object(id=int(data[0]["id"]))
         return data
 
-    async def _retrieve_guilds_after_strategy(self, retrieve):
+    async def _retrieve_guilds_after_strategy(self, retrieve: int) -> List[GuildPayload]:
         """Retrieve guilds using after parameter."""
         after = self.after.id if self.after else None
-        data: List[GuildPayload] = await self.get_guilds(retrieve, after=after)
+        data: List[GuildPayload] = await self.bot.http.get_guilds(retrieve, after=after)
         if len(data):
             if self.limit is not None:
                 self.limit -= retrieve
@@ -723,18 +728,22 @@ class GuildIterator(_AsyncIterator["Guild"]):
 
 
 class MemberIterator(_AsyncIterator["Member"]):
-    def __init__(self, guild, limit=1000, after=None):
-
+    def __init__(
+        self,
+        guild: Guild,
+        limit: Optional[int] = 1000,
+        after: Optional[Union[Snowflake, datetime.datetime]] = None,
+    ) -> None:
         if isinstance(after, datetime.datetime):
             after = Object(id=time_snowflake(after, high=True))
 
-        self.guild = guild
-        self.limit = limit
-        self.after = after or OLDEST_OBJECT
+        self.retrieve: int
+        self.guild: Guild = guild
+        self.limit: Optional[int] = limit
+        self.after: Snowflake = after or OLDEST_OBJECT
 
-        self.state = self.guild._state
-        self.get_members = self.state.http.get_members
-        self.members = asyncio.Queue()
+        self.state: ConnectionState = self.guild._state
+        self.members: asyncio.Queue[Member] = asyncio.Queue()
 
     async def next(self) -> Member:
         if self.members.empty():
@@ -754,10 +763,10 @@ class MemberIterator(_AsyncIterator["Member"]):
         self.retrieve = r
         return r > 0
 
-    async def fill_members(self):
+    async def fill_members(self) -> None:
         if self._get_retrieve():
             after = self.after.id if self.after else None
-            data = await self.get_members(self.guild.id, self.retrieve, after)
+            data = await self.state.http.get_members(self.guild.id, self.retrieve, after)
             if not data:
                 # no data, terminate
                 return
@@ -770,7 +779,7 @@ class MemberIterator(_AsyncIterator["Member"]):
             for element in reversed(data):
                 await self.members.put(self.create_member(element))
 
-    def create_member(self, data):
+    def create_member(self, data: MemberWithUser) -> Member:
         from .member import Member
 
         return Member(data=data, guild=self.guild, state=self.state)
@@ -785,13 +794,13 @@ class ArchivedThreadIterator(_AsyncIterator["Thread"]):
         joined: bool,
         private: bool,
         before: Optional[Union[Snowflake, datetime.datetime]] = None,
-    ):
-        self.channel_id = channel_id
-        self.guild = guild
-        self.limit = limit
-        self.joined = joined
-        self.private = private
-        self.http = guild._state.http
+    ) -> None:
+        self.channel_id: int = channel_id
+        self.guild: Guild = guild
+        self.limit: Optional[int] = limit
+        self.joined: bool = joined
+        self.private: bool = private
+        self.http: HTTPClient = guild._state.http
 
         if joined and not private:
             raise ValueError("Cannot iterate over joined public archived threads")
@@ -812,6 +821,7 @@ class ArchivedThreadIterator(_AsyncIterator["Thread"]):
 
         self.update_before: Callable[[ThreadPayload], str] = self.get_archive_timestamp
 
+        self.endpoint: Callable[..., Awaitable[ThreadPaginationPayload]]
         if joined:
             self.endpoint = self.http.get_joined_private_archived_threads
             self.update_before = self.get_thread_id
@@ -868,16 +878,15 @@ class ArchivedThreadIterator(_AsyncIterator["Thread"]):
 
 
 class ScheduledEventIterator(_AsyncIterator["ScheduledEvent"]):
-    def __init__(self, guild: Guild, with_users: bool = False):
-        self.guild = guild
-        self.with_users = with_users
+    def __init__(self, guild: Guild, with_users: bool = False) -> None:
+        self.guild: Guild = guild
+        self.with_users: bool = with_users
 
-        self.state = self.guild._state
-        self.get_guild_events = self.state.http.get_guild_events
-        self.queue = asyncio.Queue()
-        self.has_more = True
+        self.state: ConnectionState = self.guild._state
+        self.queue: asyncio.Queue[ScheduledEvent] = asyncio.Queue()
+        self.has_more: bool = True
 
-    async def next(self) -> Member:
+    async def next(self) -> ScheduledEvent:
         if self.queue.empty():
             await self.fill_queue()
 
@@ -886,11 +895,11 @@ class ScheduledEventIterator(_AsyncIterator["ScheduledEvent"]):
         except asyncio.QueueEmpty:
             raise NoMoreItems()
 
-    async def fill_queue(self):
+    async def fill_queue(self) -> None:
         if not self.has_more:
             raise NoMoreItems()
 
-        data = await self.get_guild_events(self.guild.id, self.with_users)
+        data = await self.state.http.get_guild_events(self.guild.id, self.with_users)
         self.has_more = False
         if not data:
             # no data, terminate
@@ -899,7 +908,7 @@ class ScheduledEventIterator(_AsyncIterator["ScheduledEvent"]):
         for element in reversed(data):
             await self.queue.put(self.create_event(element))
 
-    def create_event(self, data):
+    def create_event(self, data: ScheduledEventPayload) -> ScheduledEvent:
         return self.guild._store_scheduled_event(data)
 
 
@@ -912,26 +921,26 @@ class ScheduledEventUserIterator(_AsyncIterator["ScheduledEventUser"]):
         limit: Optional[int] = None,
         before: Optional[Snowflake] = None,
         after: Optional[Snowflake] = None,
-    ):
-        self.guild = guild
-        self.event = event
-        self.with_member = with_member
+    ) -> None:
+        self.guild: Guild = guild
+        self.event: ScheduledEvent = event
+        self.with_member: bool = with_member
 
-        self.limit = limit
-        self.before = before
-        self.after = after or OLDEST_OBJECT
+        self.limit: Optional[int] = limit
+        self.before: Optional[Snowflake] = before
+        self.after: Snowflake = after or OLDEST_OBJECT
 
         if self.before:
             self._retrieve_users = self._retrieve_users_before_strategy
         else:
             self._retrieve_users = self._retrieve_users_after_strategy
 
-        self.state = self.guild._state
-        self.get_event_users = self.state.http.get_event_users
-        self.queue = asyncio.Queue()
+        self.retrieve: int
+        self.state: ConnectionState = self.guild._state
+        self.queue: asyncio.Queue[ScheduledEventUser] = asyncio.Queue()
         self.has_more = True
 
-    async def next(self) -> Member:
+    async def next(self) -> ScheduledEventUser:
         if self.queue.empty():
             await self.fill_queue()
 
@@ -944,7 +953,7 @@ class ScheduledEventUserIterator(_AsyncIterator["ScheduledEventUser"]):
         self.retrieve = min(self.limit, 100) if self.limit is not None else 100
         return self.retrieve > 0
 
-    async def fill_queue(self):
+    async def fill_queue(self) -> None:
         if self._get_retrieve():
             data = await self._retrieve_users(self.retrieve)
             if len(data) < 100:
@@ -953,7 +962,7 @@ class ScheduledEventUserIterator(_AsyncIterator["ScheduledEventUser"]):
             for element in reversed(data):
                 await self.queue.put(self.create_user(element))
 
-    def create_user(self, data):
+    def create_user(self, data: ScheduledEventUserPayload) -> ScheduledEventUser:
         return self.event._update_user(data=data)
 
     async def _retrieve_users_before_strategy(
@@ -961,7 +970,7 @@ class ScheduledEventUserIterator(_AsyncIterator["ScheduledEventUser"]):
     ) -> List[ScheduledEventUserPayload]:
         """Retrieve users using before parameter."""
         before = self.before.id if self.before else None
-        data: List[ScheduledEventUserPayload] = await self.get_event_users(
+        data: List[ScheduledEventUserPayload] = await self.state.http.get_event_users(
             self.guild.id, self.event.id, limit=retrieve, before=before
         )
         if len(data):
@@ -975,7 +984,7 @@ class ScheduledEventUserIterator(_AsyncIterator["ScheduledEventUser"]):
     ) -> List[ScheduledEventUserPayload]:
         """Retrieve users using after parameter."""
         after = self.after.id if self.after else None
-        data: List[ScheduledEventUserPayload] = await self.get_event_users(
+        data: List[ScheduledEventUserPayload] = await self.state.http.get_event_users(
             self.guild.id, self.event.id, limit=retrieve, after=after
         )
         if len(data):
