@@ -1,27 +1,4 @@
-"""
-The MIT License (MIT)
-
-Copyright (c) 2015-2021 Rapptz
-Copyright (c) 2022-present tag-epic
-
-Permission is hereby granted, free of charge, to any person obtaining a
-copy of this software and associated documentation files (the "Software"),
-to deal in the Software without restriction, including without limitation
-the rights to use, copy, modify, merge, publish, distribute, sublicense,
-and/or sell copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
-OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-DEALINGS IN THE SOFTWARE.
-"""
+# SPDX-License-Identifier: MIT
 
 from __future__ import annotations
 
@@ -29,6 +6,7 @@ import asyncio
 import time
 from typing import TYPE_CHECKING, Callable, Dict, Iterable, List, Optional, Union
 
+from . import channel
 from .abc import Messageable
 from .enums import ChannelType, try_enum
 from .errors import ClientException
@@ -45,7 +23,7 @@ if TYPE_CHECKING:
     from datetime import datetime
 
     from .abc import Snowflake, SnowflakeTime
-    from .channel import CategoryChannel, TextChannel
+    from .channel import CategoryChannel, ForumChannel, ForumTag, TextChannel
     from .guild import Guild
     from .member import Member
     from .message import Message, PartialMessage
@@ -130,6 +108,10 @@ class Thread(Messageable, Hashable, PinsMixin):
         This is ``None`` if the thread was created before January 9th, 2021.
 
         .. versionadded:: 2.0
+    applied_tag_ids: List[:class:`int`]
+        A list of tag IDs that have been applied to this thread.
+
+        .. versionadded:: 2.4
     """
 
     __slots__ = (
@@ -154,9 +136,10 @@ class Thread(Messageable, Hashable, PinsMixin):
         "archive_timestamp",
         "create_timestamp",
         "flags",
+        "applied_tag_ids",
     )
 
-    def __init__(self, *, guild: Guild, state: ConnectionState, data: ThreadPayload):
+    def __init__(self, *, guild: Guild, state: ConnectionState, data: ThreadPayload) -> None:
         self._state: ConnectionState = state
         self.guild = guild
         self._members: Dict[int, ThreadMember] = {}
@@ -174,7 +157,7 @@ class Thread(Messageable, Hashable, PinsMixin):
     def __str__(self) -> str:
         return self.name
 
-    def _from_data(self, data: ThreadPayload):
+    def _from_data(self, data: ThreadPayload) -> None:
         self.id = int(data["id"])
         self.parent_id = int(data["parent_id"])
         self.owner_id = int(data["owner_id"])
@@ -194,7 +177,11 @@ class Thread(Messageable, Hashable, PinsMixin):
         else:
             self.me = ThreadMember(self, member)
 
-    def _unroll_metadata(self, data: ThreadMetadata):
+        self.applied_tag_ids: List[int] = [
+            int(tag_id) for tag_id in data.get("applied_thread_tags", [])
+        ]
+
+    def _unroll_metadata(self, data: ThreadMetadata) -> None:
         self.archived = data["archived"]
         self.archiver_id = get_as_snowflake(data, "archiver_id")
         self.auto_archive_duration = data["auto_archive_duration"]
@@ -203,7 +190,7 @@ class Thread(Messageable, Hashable, PinsMixin):
         self.invitable = data.get("invitable", True)
         self.create_timestamp = parse_time(data.get("create_timestamp"))
 
-    def _update(self, data):
+    def _update(self, data) -> None:
         try:
             self.name = data["name"]
         except KeyError:
@@ -232,8 +219,8 @@ class Thread(Messageable, Hashable, PinsMixin):
         return self._type
 
     @property
-    def parent(self) -> Optional[TextChannel]:
-        """Optional[:class:`TextChannel`]: The parent channel this thread belongs to."""
+    def parent(self) -> Optional[Union[TextChannel, ForumChannel]]:
+        """Optional[Union[:class:`TextChannel`, :class:`ForumChannel`]]: The parent channel this thread belongs to."""
         return self.guild.get_channel(self.parent_id)  # type: ignore
 
     @property
@@ -325,6 +312,32 @@ class Thread(Messageable, Hashable, PinsMixin):
         """
         return f"https://discord.com/channels/{self.guild.id}/{self.id}"
 
+    @property
+    def applied_tags(self) -> Optional[List[ForumTag]]:
+        """Optional[List[:class:`ForumTag`]]: A list of tags applied to this thread.
+
+        This is ``None`` if the parent channel was not found in cache.
+
+        .. versionadded:: 2.4
+        """
+
+        if self.parent is None:
+            return None
+
+        parent = self.parent
+
+        if not isinstance(parent, channel.ForumChannel):
+            return None
+
+        tags: List[ForumTag] = []
+
+        for tag_id in self.applied_tag_ids:
+            tag = parent.get_tag(tag_id)
+            if tag is not None:
+                tags.append(tag)
+
+        return tags
+
     def is_private(self) -> bool:
         """:class:`bool`: Whether the thread is a private thread.
 
@@ -512,7 +525,7 @@ class Thread(Messageable, Hashable, PinsMixin):
 
         minimum_time = int((time.time() - 14 * 24 * 60 * 60) * 1000.0 - 1420070400000) << 22
 
-        async def _single_delete_strategy(messages: Iterable[Message]):
+        async def _single_delete_strategy(messages: Iterable[Message]) -> None:
             for m in messages:
                 await m.delete()
 
@@ -563,6 +576,7 @@ class Thread(Messageable, Hashable, PinsMixin):
         slowmode_delay: int = MISSING,
         auto_archive_duration: ThreadArchiveDuration = MISSING,
         flags: ChannelFlags = MISSING,
+        applied_tags: List[ForumTag] = MISSING,
     ) -> Thread:
         """|coro|
 
@@ -596,6 +610,10 @@ class Thread(Messageable, Hashable, PinsMixin):
             The new channel flags to use for this thread.
 
             .. versionadded:: 2.1
+        applied_tags: List[:class:`ForumTag`]
+            The new tags to apply to this thread.
+
+            .. versionadded:: 2.4
 
         Raises
         ------
@@ -624,12 +642,14 @@ class Thread(Messageable, Hashable, PinsMixin):
             payload["rate_limit_per_user"] = slowmode_delay
         if flags is not MISSING:
             payload["flags"] = flags.value
+        if applied_tags is not MISSING:
+            payload["applied_tags"] = [tag.id for tag in applied_tags]
 
         data = await self._state.http.edit_channel(self.id, **payload)
         # The data payload will always be a Thread payload
         return Thread(data=data, state=self._state, guild=self.guild)  # type: ignore
 
-    async def join(self):
+    async def join(self) -> None:
         """|coro|
 
         Joins this thread.
@@ -646,7 +666,7 @@ class Thread(Messageable, Hashable, PinsMixin):
         """
         await self._state.http.join_thread(self.id)
 
-    async def leave(self):
+    async def leave(self) -> None:
         """|coro|
 
         Leaves this thread.
@@ -658,7 +678,7 @@ class Thread(Messageable, Hashable, PinsMixin):
         """
         await self._state.http.leave_thread(self.id)
 
-    async def add_user(self, user: Snowflake):
+    async def add_user(self, user: Snowflake) -> None:
         """|coro|
 
         Adds a user to this thread.
@@ -682,7 +702,7 @@ class Thread(Messageable, Hashable, PinsMixin):
         """
         await self._state.http.add_user_to_thread(self.id, user.id)
 
-    async def remove_user(self, user: Snowflake):
+    async def remove_user(self, user: Snowflake) -> None:
         """|coro|
 
         Removes a user from this thread.
@@ -725,7 +745,7 @@ class Thread(Messageable, Hashable, PinsMixin):
         members = await self._state.http.get_thread_members(self.id)
         return [ThreadMember(parent=self, data=data) for data in members]
 
-    async def delete(self):
+    async def delete(self) -> None:
         """|coro|
 
         Deletes this thread.
@@ -813,7 +833,7 @@ class ThreadMember(Hashable):
         "parent",
     )
 
-    def __init__(self, parent: Thread, data: ThreadMemberPayload):
+    def __init__(self, parent: Thread, data: ThreadMemberPayload) -> None:
         self.parent = parent
         self._state = parent._state
         self._from_data(data)
@@ -823,7 +843,7 @@ class ThreadMember(Hashable):
             f"<ThreadMember id={self.id} thread_id={self.thread_id} joined_at={self.joined_at!r}>"
         )
 
-    def _from_data(self, data: ThreadMemberPayload):
+    def _from_data(self, data: ThreadMemberPayload) -> None:
         try:
             self.id = int(data["user_id"])
         except KeyError:
